@@ -1,6 +1,6 @@
 ##
 ## R package splines2 by Wenjie Wang and Jun Yan
-## Copyright (C) 2016-2020
+## Copyright (C) 2016-2021
 ##
 ## This file is part of the R package splines2.
 ##
@@ -18,42 +18,46 @@
 ##' B-Spline Basis for Polynomial Splines
 ##'
 ##' Generates the B-spline basis matrix representing the family of piecewise
-##' polynomials with the specified interior knots and degree, evaluated at the
-##' values of \code{x}.
+##' polynomials with the specified interior knots, degree, and boundary knots,
+##' evaluated at the values of \code{x}.
 ##'
-##' This function extends the \code{bs()} function in \code{splines} package for
-##' B-spline basis by allowing piecewise constant (left-closed and right-open
-##' except on the right boundary) spline basis with zero degree.
+##' This function extends the \code{bs()} function in the \code{splines} package
+##' for B-spline basis by allowing piecewise constant (left-closed and
+##' right-open except on the right boundary) spline basis of degree zero.
 ##'
 ##' @param x The predictor variable.  Missing values are allowed and will be
 ##'     returned as they are.
-##' @param df Degree of freedom that equals to the column number of returned
+##' @param df Degree of freedom that equals to the column number of the returned
 ##'     matrix.  One can specify \code{df} rather than \code{knots}, then the
 ##'     function chooses \code{df - degree - as.integer(intercept)} internal
 ##'     knots at suitable quantiles of \code{x} ignoring missing values and
 ##'     those \code{x} outside of the boundary.  If internal knots are specified
 ##'     via \code{knots}, the specified \code{df} will be ignored.
-##' @param knots The internal breakpoints that define the spline.  The default
+##' @param knots The internal breakpoints that define the splines.  The default
 ##'     is \code{NULL}, which results in a basis for ordinary polynomial
 ##'     regression.  Typical values are the mean or median for one knot,
 ##'     quantiles for more knots.
-##' @param degree A non-negative integer specifying the degree of the piecewise
-##'     polynomial. The default value is 3 for cubic splines. Zero degree is
-##'     allowed for piece-wise constant bases.
+##' @param degree A nonnegative integer specifying the degree of the piecewise
+##'     polynomial. The default value is \code{3} for cubic splines. Zero degree
+##'     is allowed for piecewise constant basis functions.
 ##' @param intercept If \code{TRUE}, the complete basis matrix will be returned.
 ##'     Otherwise, the first basis will be excluded from the output.
-##' @param Boundary.knots Boundary points at which to anchor the spline basis.
-##'     By default, they are the range of the non-\code{NA} data.  If both
+##' @param Boundary.knots Boundary points at which to anchor the splines.  By
+##'     default, they are the range of \code{x} excluding \code{NA}.  If both
 ##'     \code{knots} and \code{Boundary.knots} are supplied, the basis
 ##'     parameters do not depend on \code{x}. Data can extend beyond
 ##'     \code{Boundary.knots}.
 ##' @param ... Optional arguments that are not used.
 ##'
-##' @return A numeric matrix with \code{length(x)} rows and \code{df} columns if
+##' @return A numeric matrix of \code{length(x)} rows and \code{df} columns if
 ##'     \code{df} is specified or \code{length(knots) + degree +
 ##'     as.integer(intercept)} columns if \code{knots} are specified instead.
-##'     Attributes that correspond to the arguments specified are returned for
-##'     usage of other functions in this package.
+##'     Attributes that correspond to the arguments specified are returned
+##'     mainly for other functions in this package.
+##'
+##' @references
+##' De Boor, Carl. (1978). \emph{A practical guide to splines}.
+##' Vol. 27. New York: Springer-Verlag.
 ##'
 ##' @example inst/examples/ex-bSpline.R
 ##'
@@ -67,13 +71,13 @@ bSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
 {
     ## check inputs
     if ((degree <- as.integer(degree)) < 0)
-        stop("'degree' must be a nonnegative integer.")
+        stop("The 'degree' must be a nonnegative integer.")
     if (is.null(df)) {
         df <- 0L
     } else {
         df <- as.integer(df)
         if (df < 0) {
-            stop("'df' must be a nonnegative integer.")
+            stop("The 'df' must be a nonnegative integer.")
         }
     }
     knots <- null2num0(knots)
@@ -103,7 +107,7 @@ bSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
     if (any((xx < b_knots[1L]) | (xx > b_knots[2L]))) {
         warning(wrapMessages(
             "Some 'x' values beyond boundary knots",
-            "may cause ill-conditioned bases."
+            "may cause ill-conditioned basis functions."
         ))
     }
     ## keep NA's as is
