@@ -1,6 +1,6 @@
 ##
 ## R package splines2 by Wenjie Wang and Jun Yan
-## Copyright (C) 2016-2020
+## Copyright (C) 2016-2021
 ##
 ## This file is part of the R package splines2.
 ##
@@ -21,15 +21,17 @@
 ##'
 ##' These are methods for the generic function \code{predict} for objects
 ##' inheriting from class \code{bSpline2}, \code{ibs}, \code{mSpline},
-##' \code{iSpline}, \code{cSpline}, or \code{bernsteinPoly}.  If \code{newx} is
-##' not given, the function returns the input object.
+##' \code{iSpline}, \code{cSpline}, \code{naturalSpline}, or
+##' \code{bernsteinPoly}.  If \code{newx} is not given, the function returns the
+##' input object.
 ##'
 ##' @name predict
 ##' @param object Objects of class \code{bSpline2}, \code{ibs}, \code{mSpline},
-##'     \code{iSpline}, \code{cSpline}, or \code{bernsteinPoly} with attributes
-##'     describing \code{knots}, \code{degree}, etc.
+##'     \code{iSpline}, \code{cSpline}, \code{bernsteinPoly} or
+##'     \code{naturalSpline} with attributes describing \code{knots},
+##'     \code{degree}, etc.
 ##' @param newx The \code{x} values at which evaluations are required.
-##' @param ... Optional argument that are not used.
+##' @param ... Optional arguments that are not used.
 ##'
 ##' @return
 ##' An object just like the \code{object} input, except evaluated at
@@ -37,14 +39,6 @@
 ##'
 ##' @example inst/examples/ex-predict.R
 ##'
-##' @seealso
-##' \code{\link{bSpline}} for B-splines;
-##' \code{\link{ibs}} for integrals of B-splines;
-##' \code{\link{dbs}} for derivatives of B-splines;
-##' \code{\link{mSpline}} for M-splines;
-##' \code{\link{iSpline}} for I-splines;
-##' \code{\link{cSpline}} for C-splines.
-##'
 ##' @importFrom stats predict
 NULL
 
@@ -55,23 +49,9 @@ predict.bSpline2 <- function(object, newx, ...)
 {
     if (missing(newx))
         return(object)
-    a <- c(list(x = newx),
-           attributes(object)[c("degree", "knots", "Boundary.knots",
-                                "intercept")])
-    do.call("bSpline", a)
-}
-
-
-##' @rdname predict
-##' @export
-predict.ibs <- function(object, newx, ...)
-{
-    if (missing(newx))
-        return(object)
-    a <- c(list(x = newx),
-           attributes(object)[c("degree", "knots", "Boundary.knots",
-                                "intercept")])
-    do.call("ibs", a)
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "degree", "knots", "Boundary.knots", "intercept"))
+    do.call(bSpline, c(list(x = newx), pred_attr(object)))
 }
 
 
@@ -81,10 +61,23 @@ predict.dbs <- function(object, newx, ...)
 {
     if (missing(newx))
         return(object)
-    a <- c(list(x = newx),
-           attributes(object)[c("degree", "knots", "Boundary.knots",
-                                "intercept", "derivs")])
-    do.call("dbs", a)
+    ## checks if key attributes still exist
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "degree", "derivs",
+                         "knots", "Boundary.knots", "intercept"))
+    do.call(dbs, c(list(x = newx), pred_attr(object)))
+}
+
+
+##' @rdname predict
+##' @export
+predict.ibs <- function(object, newx, ...)
+{
+    if (missing(newx))
+        return(object)
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "degree", "knots", "Boundary.knots", "intercept"))
+    do.call(ibs, c(list(x = newx), pred_attr(object)))
 }
 
 
@@ -94,10 +87,10 @@ predict.mSpline <- function(object, newx, ...)
 {
     if (missing(newx))
         return(object)
-    a <- c(list(x = newx),
-           attributes(object)[c("degree", "knots", "Boundary.knots",
-                                "intercept", "derivs")])
-    do.call("mSpline", a)
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "degree", "derivs", "integral", "periodic",
+                         "knots", "Boundary.knots", "intercept"))
+    do.call(mSpline, c(list(x = newx), pred_attr(object)))
 }
 
 
@@ -107,10 +100,10 @@ predict.iSpline <- function(object, newx, ...)
 {
     if (missing(newx))
         return(object)
-    a <- c(list(x = newx),
-           attributes(object)[c("degree", "knots", "Boundary.knots",
-                                "intercept", "derivs")])
-    do.call("iSpline", a)
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "degree", "derivs",
+                         "knots", "Boundary.knots", "intercept"))
+    do.call(iSpline, c(list(x = newx), pred_attr(object)))
 }
 
 
@@ -120,10 +113,10 @@ predict.cSpline <- function(object, newx, ...)
 {
     if (missing(newx))
         return(object)
-    a <- c(list(x = newx),
-           attributes(object)[c("degree", "knots", "Boundary.knots",
-                                "intercept", "scale")])
-    do.call("cSpline", a)
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "degree", "derivs",
+                         "knots", "Boundary.knots", "intercept"))
+    do.call(cSpline, c(list(x = newx), pred_attr(object)))
 }
 
 
@@ -133,8 +126,21 @@ predict.bernsteinPoly <- function(object, newx, ...)
 {
     if (missing(newx))
         return(object)
-    a <- c(list(x = newx),
-           attributes(object)[c("degree", "derivs", "integral",
-                                "intercept", "Boundary.knots")])
-    do.call("bernsteinPoly", a)
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "degree", "derivs", "integral",
+                         "Boundary.knots", "intercept"))
+    do.call(bernsteinPoly, c(list(x = newx), pred_attr(object)))
+}
+
+
+##' @rdname predict
+##' @export
+predict.naturalSpline <- function(object, newx, ...)
+{
+    if (missing(newx))
+        return(object)
+    ## checks if key attributes still exist
+    check_attr(object, c("x", "derivs", "integral",
+                         "knots", "Boundary.knots", "intercept"))
+    do.call(naturalSpline, c(list(x = newx), pred_attr(object)))
 }
